nontree.QuadTree API documentation

# nontree.QuadTree

class QuadTree(nontree.NonTree.NonTree):

A class for efficient collision detection of points in a sparse 2D plane.
Based on the well known Quadtree data structure.
This is a variant that splits each plane into 4 sub-trees in a 2 by 2 grid.

##### Inherited Members

nontree.NonTree.NonTree
  NonTree
  add
  discard
  get_encompassed
  get_rect
  get_circle
  get_point
  test_rect
  test_circle
  test_point
  del_encompassed
  del_rect
  del_circle
  del_point
  prune
  encompass_rectrect
  collide_rectpoint
  collide_rectrect
  encompass_circlerect
  collide_rectcircle
  collide_circlepoint